@@ -1,6 +1,6 @@
 from unittest.mock import Mock, patch
 
-from ai_assistant_manager.exporters.exporter import create_dir, does_data_exist
+from .exporter import create_dir, does_data_exist
 
 
 def test_does_data_exist():
@@ -13,7 +13,7 @@ def test_does_data_exist():
 
 
 @patch("ai_assistant_manager.exporters.exporter.does_data_exist")
-def test_create_dir_data_exists(mock_does_data_exist):
+def test_create_dir_data_exists(mock_does_data_exist: Mock):
     mock_does_data_exist.return_value = True
 
     with patch("os.makedirs") as mock_makedirs:
@@ -23,7 +23,7 @@ def test_create_dir_data_exists(mock_does_data_exist):
 
 
 @patch("ai_assistant_manager.exporters.exporter.does_data_exist")
-def test_create_dir_data_does_not_exist(mock_does_data_exist):
+def test_create_dir_data_does_not_exist(mock_does_data_exist: Mock):
     mock_does_data_exist.return_value = False
 
     with patch("os.makedirs") as mock_makedirs:
