@@ -1,6 +1,6 @@
 from unittest.mock import patch
 
-from ai_assistant_manager.timer.timer import timer
+from .timer import timer
 
 
 def test_timer_decorator():
@@ -11,5 +11,6 @@ def test_timer_decorator():
     with patch("ai_assistant_manager.timer.timer.logger") as mock_logger:
         dummy_function()
 
+    # Ensure the logger is called once with the expected message
     mock_logger.debug.assert_called_once()
     assert "Test function: completed in" in mock_logger.debug.call_args[0][0]
